API
====

:mod:`underthesea` Package
-------------------

.. automodule:: underthesea
    :members:
    :undoc-members:

.. automodule:: underthesea.underthesea
    :members:
    :undoc-members:

:mod:`corpus` Package
-------------------

.. automodule:: underthesea.corpus
    :members:
    :undoc-members:

.. automodule:: underthesea.corpus.corpus
    :members:
    :undoc-members:

.. automodule:: underthesea.corpus.plaintext
    :members:
    :undoc-members:
